@@ -494,7 +494,7 @@ our %Modules = (
     },
 
     'ExtUtils::MakeMaker' => {
-        'DISTRIBUTION' => 'BINGOS/ExtUtils-MakeMaker-7.72.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/ExtUtils-MakeMaker-7.74.tar.gz',
         'SYNCINFO'     => 'yorton on Sun Mar 26 16:20:23 2023',
         'FILES'        => q[cpan/ExtUtils-MakeMaker],
         'EXCLUDED'     => [
@@ -765,8 +765,8 @@ our %Modules = (
     },
 
     'Math::BigInt' => {
-        'DISTRIBUTION' => 'PJACKLAM/Math-BigInt-2.004001.tar.gz',
-        'SYNCINFO'     => 'mauke on Wed Mar 19 06:15:30 2025',
+        'DISTRIBUTION' => 'PJACKLAM/Math-BigInt-2.005002.tar.gz',
+        'SYNCINFO'     => 'jkeenan on Thu Apr 10 20:38:17 2025',
         'FILES'        => q[cpan/Math-BigInt],
         'EXCLUDED'     => [
             qr{^xt/},
@@ -778,8 +778,8 @@ our %Modules = (
     },
 
     'Math::BigInt::FastCalc' => {
-        'DISTRIBUTION' => 'PJACKLAM/Math-BigInt-FastCalc-0.5019.tar.gz',
-        'SYNCINFO'     => 'mauke on Wed Mar 19 06:31:57 2025',
+        'DISTRIBUTION' => 'PJACKLAM/Math-BigInt-FastCalc-0.5020.tar.gz',
+        'SYNCINFO'     => 'jkeenan on Thu Apr 10 20:46:45 2025',
         'FILES'        => q[cpan/Math-BigInt-FastCalc],
         'EXCLUDED'     => [
             qr{^inc/},
@@ -832,7 +832,7 @@ our %Modules = (
     },
 
     'Module::CoreList' => {
-        'DISTRIBUTION' => 'BINGOS/Module-CoreList-5.20250220.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/Module-CoreList-5.20250321.tar.gz',
         'FILES'        => q[dist/Module-CoreList],
     },
 
@@ -976,7 +976,8 @@ our %Modules = (
     },
 
     'Pod::Usage' => {
-        'DISTRIBUTION' => 'MAREKR/Pod-Usage-2.03.tar.gz',
+        'DISTRIBUTION' => 'MAREKR/Pod-Usage-2.05.tar.gz',
+        'SYNCINFO'     => 'jkeenan on Sun Mar 30 10:25:52 2025',
         'FILES'        => q[cpan/Pod-Usage],
         'EXCLUDED' => [
             qr{^t/00-},
@@ -1007,8 +1008,8 @@ our %Modules = (
     },
 
     'Scalar::Util' => {
-        'DISTRIBUTION' => 'PEVANS/Scalar-List-Utils-1.68.tar.gz',
-        'SYNCINFO'     => 'rich on Sun Oct 20 15:42:58 2024',
+        'DISTRIBUTION' => 'PEVANS/Scalar-List-Utils-1.69.tar.gz',
+        'SYNCINFO'     => 'jkeenan on Thu Apr 10 21:01:49 2025',
         'FILES'        => q[cpan/Scalar-List-Utils],
         'CUSTOMIZED'   => [
             'ListUtil.xs',
@@ -1125,8 +1126,8 @@ our %Modules = (
     },
 
     'Test::Simple' => {
-        'DISTRIBUTION' => 'EXODIST/Test-Simple-1.302209.tar.gz',
-        'SYNCINFO'     => 'eric on Wed Feb  5 17:23:19 2025',
+        'DISTRIBUTION' => 'EXODIST/Test-Simple-1.302210.tar.gz',
+        'SYNCINFO'     => 'jkeenan on Tue Apr  1 20:47:53 2025',
         'FILES'        => q[cpan/Test-Simple],
         'EXCLUDED'     => [
             qr{^examples/},
@@ -1260,8 +1261,8 @@ our %Modules = (
     },
 
     'Time::Piece' => {
-        'DISTRIBUTION' => 'PEVANS/Time-Piece-1.35.tar.gz',
-        'SYNCINFO'     => 'LeoNerd on Fri Jan 17 15:27:02 2025',
+        'DISTRIBUTION' => 'ESAYM/Time-Piece-1.36.tar.gz',
+        'SYNCINFO'     => 'jkeenan on Fri Apr 11 07:13:44 2025',
         'FILES'        => q[cpan/Time-Piece],
         'EXCLUDED'     => [ qw[reverse_deps.txt] ],
     },
