@@ -37,11 +37,15 @@ Perl_newSVobject(pTHX_ Size_t fieldcount)
 {
     SV *sv = newSV_type(SVt_PVOBJ);
 
-    Newx(ObjectFIELDS(sv), fieldcount, SV *);
+    if (fieldcount) {
+        Newx(ObjectFIELDS(sv), fieldcount, SV *);
+        Zero(ObjectFIELDS(sv), fieldcount, SV *);
+    }
+    else {
+        ObjectFIELDS(sv) = NULL;
+    }
     ObjectMAXFIELD(sv) = fieldcount - 1;
 
-    Zero(ObjectFIELDS(sv), fieldcount, SV *);
-
     return sv;
 }
 
@@ -98,8 +102,7 @@ PP(pp_initfield)
                 STRLEN svcount = PL_stack_sp - svp + 1;
 
                 if(svcount % 2)
-                    Perl_warner(aTHX_
-                            packWARN(WARN_MISC), "Odd number of elements in hash field initialization");
+                    warner(packWARN(WARN_MISC), "Odd number of elements in hash field initialization");
 
                 while(svp <= PL_stack_sp) {
                     SV *key = *svp; svp++;
@@ -137,11 +140,11 @@ XS(injected_constructor)
     struct xpvhv_aux *aux = HvAUX(stash);
 
     if((items - 1) % 2)
-        Perl_warn(aTHX_ "Odd number of arguments passed to %" HvNAMEf_QUOTEDPREFIX " constructor",
+        warn("Odd number of arguments passed to %" HvNAMEf_QUOTEDPREFIX " constructor",
                 HvNAMEfARG(stash));
 
     if (!aux->xhv_class_initfields_cv) {
-        Perl_croak(aTHX_ "Cannot create an object of incomplete class %" HvNAMEf_QUOTEDPREFIX,
+        croak("Cannot create an object of incomplete class %" HvNAMEf_QUOTEDPREFIX,
                    HvNAMEfARG(stash));
     }
 
@@ -168,10 +171,12 @@ XS(injected_constructor)
 
     SV *instance = newSVobject(aux->xhv_class_next_fieldix);
     SvOBJECT_on(instance);
-    SvSTASH_set(instance, MUTABLE_HV(SvREFCNT_inc_simple(stash)));
+    SvSTASH_set(instance, HvREFCNT_inc_simple(stash));
 
     SV *self = sv_2mortal(newRV_noinc(instance));
 
+    PUSHSTACKi(PERLSI_CONSTRUCTOR);
+
     assert(aux->xhv_class_initfields_cv);
     {
         ENTER;
@@ -218,6 +223,9 @@ XS(injected_constructor)
         }
     }
 
+    POPSTACK;
+    SPAGAIN;
+
     if(params && hv_iterinit(params) > 0) {
         /* TODO: consider sorting these into a canonical order, but that's awkward */
         HE *he = hv_iternext(params);
@@ -226,7 +234,7 @@ XS(injected_constructor)
         SAVEFREESV(paramnames);
 
         while((he = hv_iternext(params)))
-            Perl_sv_catpvf(aTHX_ paramnames, ", %" SVf, SVfARG(HeSVKEY_force(he)));
+            sv_catpvf(paramnames, ", %" SVf, SVfARG(HeSVKEY_force(he)));
 
         croak("Unrecognised parameters for %" HvNAMEf_QUOTEDPREFIX " constructor: %" SVf,
                 HvNAMEfARG(stash), SVfARG(paramnames));
@@ -468,7 +476,7 @@ static void S_ensure_module_version(pTHX_ SV *module, SV *version)
 static void S_split_attr_nameval(pTHX_ SV *sv, SV **namp, SV **valp)
 {
     STRLEN svlen = SvCUR(sv);
-    bool do_utf8 = SvUTF8(sv);
+    U32 do_utf8 = SvUTF8(sv) ? SVf_UTF8 : 0;
 
     const char *paren_at = (const char *)memchr(SvPVX(sv), '(', svlen);
     if(paren_at) {
@@ -482,7 +490,7 @@ static void S_split_attr_nameval(pTHX_ SV *sv, SV **namp, SV **valp)
              */
             /* diag_listed_as: SKIPME */
             croak("Malformed attribute string");
-        *namp = sv_2mortal(newSVpvn_utf8(SvPVX(sv), namelen, do_utf8));
+        *namp = newSVpvn_flags(SvPVX(sv), namelen, SVs_TEMP|do_utf8);
 
         const char *value_at = paren_at + 1;
         const char *value_max = SvPVX(sv) + svlen - 2;
@@ -496,7 +504,7 @@ static void S_split_attr_nameval(pTHX_ SV *sv, SV **namp, SV **valp)
             value_max -= 1;
 
         if(value_max >= value_at)
-            *valp = sv_2mortal(newSVpvn_utf8(value_at, value_max - value_at + 1, do_utf8));
+            *valp = newSVpvn_flags(value_at, value_max - value_at + 1, SVs_TEMP|do_utf8);
         else
             *valp = NULL;
     }
@@ -979,6 +987,9 @@ apply_field_attribute_reader(pTHX_ PADNAME *pn, SV *value)
         /* Default to name minus the sigil */
         value = newSVpvn_utf8(PadnamePV(pn) + 1, PadnameLEN(pn) - 1, PadnameUTF8(pn));
 
+    if(!valid_identifier_sv(value))
+        croak("%" SVf_QUOTEDPREFIX " is not a valid name for a generated method", value);
+
     PADOFFSET fieldix = PadnameFIELDINFO(pn)->fieldix;
 
     I32 floor_ix = start_subparse(FALSE, 0);
@@ -1052,6 +1063,104 @@ apply_field_attribute_reader(pTHX_ PADNAME *pn, SV *value)
     CvIsMETHOD_on(cv);
 }
 
+/* If '@_' is called "snail", then elements of it can be called "slugs"; i.e.
+ * snails out of their container. */
+#define newSLUGOP(idx)  S_newSLUGOP(aTHX_ idx)
+static OP *
+S_newSLUGOP(pTHX_ IV idx)
+{
+    assert(idx >= 0 && idx <= 255);
+    OP *op = newGVOP(OP_AELEMFAST, 0, PL_defgv);
+    op->op_private = idx;
+    return op;
+}
+
+static void
+apply_field_attribute_writer(pTHX_ PADNAME *pn, SV *value)
+{
+    char sigil = PadnamePV(pn)[0];
+    if(sigil != '$')
+        croak("Cannot apply a :writer attribute to a non-scalar field");
+
+    if(value)
+        SvREFCNT_inc(value);
+    else {
+        /* Default to "set_" . name minus the sigil */
+        value = newSVpvs("set_");
+        sv_catpvn_flags(value, PadnamePV(pn) + 1, PadnameLEN(pn) - 1,
+                PadnameUTF8(pn) ? SV_CATUTF8 : 0);
+    }
+
+    if(!valid_identifier_sv(value))
+        croak("%" SVf_QUOTEDPREFIX " is not a valid name for a generated method", value);
+
+    PADOFFSET fieldix = PadnameFIELDINFO(pn)->fieldix;
+
+    I32 floor_ix = start_subparse(FALSE, 0);
+    SAVEFREESV(PL_compcv);
+
+    I32 save_ix = block_start(TRUE);
+
+    PADOFFSET padix;
+
+    padix = pad_add_name_pvs("$self", 0, NULL, NULL);
+    assert(padix == PADIX_SELF);
+
+    padix = pad_add_name_pvn(PadnamePV(pn), PadnameLEN(pn), 0, NULL, NULL);
+    intro_my();
+
+    OP *methstartop;
+    {
+        UNOP_AUX_item *aux;
+        aux = (UNOP_AUX_item *)PerlMemShared_malloc(
+                                sizeof(UNOP_AUX_item) * (2 + 2));
+
+        UNOP_AUX_item *ap = aux;
+        (ap++)->uv = 1;       /* fieldcount */
+        (ap++)->uv = fieldix; /* max_fieldix */
+
+        (ap++)->uv = padix;
+        (ap++)->uv = fieldix;
+
+        methstartop = newUNOP_AUX(OP_METHSTART, 0, NULL, aux);
+    }
+
+    OP *argcheckop;
+    {
+        struct op_argcheck_aux *aux = (struct op_argcheck_aux *)
+            PerlMemShared_malloc(sizeof(*aux));
+
+        aux->params     = 1;
+        aux->opt_params = 0;
+        aux->slurpy     = 0;
+
+        argcheckop = newUNOP_AUX(OP_ARGCHECK, 0, NULL, (UNOP_AUX_item *)aux);
+    }
+
+    OP *assignop = newBINOP(OP_SASSIGN, 0,
+            newSLUGOP(0),
+            newPADxVOP(OP_PADSV, OPf_MOD|OPf_REF, padix));
+
+    OP *retop = newLISTOP(OP_RETURN, 0,
+            newOP(OP_PUSHMARK, 0),
+            newPADxVOP(OP_PADSV, 0, PADIX_SELF));
+
+    OP *ops = newLISTOPn(OP_LINESEQ, 0,
+            methstartop,
+            argcheckop,
+            assignop,
+            retop,
+            NULL);
+
+    SvREFCNT_inc(PL_compcv);
+    ops = block_end(save_ix, ops);
+
+    OP *nameop = newSVOP(OP_CONST, 0, value);
+
+    CV *cv = newATTRSUB(floor_ix, nameop, NULL, NULL, ops);
+    CvIsMETHOD_on(cv);
+}
+
 static struct {
     const char *name;
     bool requires_value;
@@ -1065,6 +1174,10 @@ static struct {
       .requires_value = false,
       .apply          = &apply_field_attribute_reader,
     },
+    { .name           = "writer",
+      .requires_value = false,
+      .apply          = &apply_field_attribute_writer,
+    },
     { NULL, false, NULL }
 };
 
