@@ -670,7 +670,7 @@ typedef enum {
                                                    list of SVs */
 
 #if defined(PERL_IN_PERLY_C) || defined(PERL_IN_OP_C) || defined(PERL_IN_TOKE_C)
-#define Perl_ref(mTHX, o, type)  Perl_doref(aTHX_ o, type, TRUE)
+#define ref(o, type) doref(o, type, TRUE)
 #endif
 
 
@@ -1108,10 +1108,8 @@ C<sib> is non-null. For a higher-level interface, see C<L</op_sibling_splice>>.
 #  define OP_SIBLING(o)		OpSIBLING(o)
 #endif
 
-#define Perl_newATTRSUB(mTHX, f, o, p, a, b)                            \
-        Perl_newATTRSUB_x(aTHX_  f, o, p, a, b, FALSE)
-#define Perl_newSUB(mTHX, f, o, p, b)	                                \
-        Perl_newATTRSUB(aTHX, (f), (o), (p), NULL, (b))
+#define newATTRSUB(f, o, p, a, b) Perl_newATTRSUB_x(aTHX_  f, o, p, a, b, FALSE)
+#define newSUB(f, o, p, b)	newATTRSUB((f), (o), (p), NULL, (b))
 
 #ifdef USE_ITHREADS
 #  define OP_CHECK_MUTEX_INIT		MUTEX_INIT(&PL_check_mutex)
