@@ -17,6 +17,8 @@ Perl_set_context(void *t)
     TlsSetValue(PL_thr_key,t);
     SetLastError(err);
 #  endif
+    dTHXa(t);
+    PL_sys_intern.cur_tid = GetCurrentThreadId();
 #endif
 }
 
